==> whmcs-9.0.0-release.1.zip: modules/servers/hypervm/index.php <==
<?php //ICB0 82:0 83:104f                                                     ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.0 (9.0.0-release.1)                                      *
// * BuildId: db1c908403.748                                               *
// * Build Date: 20 Jan 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPrWYJyrl3RJY1f7QxXk7ycUj+1fYYu1U0ON8V74zuFAZQP7Th2WEvXcosaRrupcCcRIWJM7T
GjeXdBRdEzLs5pwuyu/Jlw2NUdC9+L61caxoockVNa6ALxx2IfX4SuLLeAIBP1nSToz1UJ8fLdgB
4sx48pgi2buIXvb000Q4fzu29yU0UdN6VdwgqS+jQK+azIHloEDNNfcZ0yVdNXqJeCYWLT3CsEub
hRty/ltQxWxbrYBi0t9mgYWqP/sYE+AMM/TNLPVJ8YgZO/rRocPoV/RRms3Vi60Q1Kbxb12SwMfA
KqScTF5QxfvRp3Mf036AWF37IlyQ2jIeyl+DqPiOr/FcVAd8hCuFTpweB+OzSjgW8UF8i2JHVXdB
6Wv+emetUB51JmcHa8011hpgArO3jYs1u7M7snzGr3PR/Xom+jo5hVsvpLqYqeRR2ZEcPDFkW0/s
s9UD8n6bkDOo/nrIApA1etTe5XrawxLm4K+p0h9/LAa/C7O9n6zRo5RX8Vn9uxJtf6sWiaW2yWMg
Fpys+KomGYZ7cyAD5vmvD1HU9tDXDdtux4YABZaUpXQh1b8WRPW/PhmGB2r7PdcPJOYBw3zjRE18
1xM2eKGHga8AOnUucDeEr82gJfh9HaiOUczVRn/kqKjR0eXQ3M5vOinvoEd1fSrIRCAoGcw/19Qh
iIzgfC3zbwlzADrhWmQ1Tbp2P8ls5s3aoFhfdGMyQEbC6Ps7v2sQhvpEeaZQGKpDZN999dGLkP7d
IM01Mnxe5xtsuT+s/ZPkzKT/SY01C9gJxSsDy0aH+S7wzHPpmTQarqqPEvAsT3FLlB00oeM2Ter4
eH1uq1jpf94BvHc6RVWuEhE3NBZYG8pwcnZ4m4In8YroZqtSrWyGDnwkRyyj7W===
HR+cPv045RtzrEsoYBg0dlCp4tRIRbRgQSpz1FK3elAU/GpifRyR0Q7BzvGshoZi20IH8AlnUUE2
sdWDyjji27ASrTZjh6Bzd9nX5jRx3hyZibLlTTzppkWFz0i2T9fptAnQfNzH5gzk9DIKDNrwgrA3
fRxfheyvNokEL9iqtTr9lBrK9jDSGdoyVVxd7ADN4xQ8ocnGmkMNrPChzzq1J3JWekqzbXHGyCdX
fczfZSSkVcsCDQKjCeLR88B2aIHBUdtuC+/YZoQ4AhfUx53s1f6PWVX90huRS2BaGPMagPAkFGl3
R75tnTEgftcs8w78FSYWvHKUdyt/9K7xEcFUjIGwtzsaTzM6CfkVI9aqwjs5jTnKU0eBw48otsKX
ECiItpy+ArGtJmSYWGxX92gfqLjDk5yoCH3FYdvC+ctsmjUFCg0IJQRjKIC/ZOIkQkXgUnwoypaB
GS4NsvA/Jw+39ThiTy+/7enLRWtOVu56GWsl+dv7dfJbjnnYVOX7XFra+Rre/H3swLm8zxIDn8fK
JgDVXkGrSEIA60b4lSbEbuviA4+45bfZbGBB0WB/dJW4aW5vMaqFBTj1W0c3NgYxnnWq0C582xm6
BNvCPReZcec1m5kQYHBzXqqqL7u+6qOw+eTRolcb//yKZDuDk3WObita0wikXsw1B4u3zht2MA39
pm9GJcUZur+ZLY51rNCJKAcRRy9uWOoSPxESz4Vusi1p063u/W0NivPa/aC5as1J8h8S8V3cmLKf
g5Fi2XDvxW7d0020QosA1DLL97l0kEYMn93TXUFFDudhqYEfSlDV4347IDvxZ+eWtPPNX/IJhxKg
2VT1hzx8S8hJKqny9g2RKiTwYmRdImm0EMJaEi8vQk9CcqAJ4x4CiHcbq535kgJA6NO=

==> whmcs-9.0.1-release.1.zip: modules/servers/hypervm/index.php <==
<?php //ICB0 82:0 83:104f                                                     ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.1 (9.0.1-release.1)                                      *
// * BuildId: 81d80f82cb.790                                               *
// * Build Date: 05 Feb 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPpbk2v1FiO+dPjsUimg6ioSC75gF+rul7iEywtiY2piRfhVsCWtWPklBoJCndGDUPjTn/r+B
kgYxM29Cot93pp864wWw3gP1t9ckdYCWftDkqIl1IkwJ2LemZb495VnuApZGLEy7Fq6cBsZ/ksst
cYGWXtkjHNV6iz7RYyjzfgXTYo82INdrZhb4Tp448XR9FSvh3HnW0oZIsv2XBPsDMKZvWceE7u/j
fJdevE81h7HHiAvEXCYDZMES01d54+BjUBDnaasAQlBkNINt+mDzKoyPJNrEY92y2vVJQbsUbtVn
uXy11clvxp2GUeWTry4/I0Zi4Wt/wZPPezAL7CbxQ9enx6lLfziHAed6jYuMtFU3/DWqAv+bviue
QKwNK5jRXRqM7hKjUtBPKA4PA5HpDYiRBvI5lyVzYm1q4iYfyqJ4U6lMdwCd137CfUInNEk+SD4x
r3U+g/iGOS7HLdi0eLcyHEUd1QmMGm8cW9/0ZbdN7IsdpQOv+YD3t9J2EyZztVpd0ihV1Z7OFwUy
RraLhpVgR47D3paUwzGqVEn8S0OtJQEtNuaqIMXfk0gaH+WTKCwnkayHazi9QwvTwew9xzT239k7
qH18FeoVeRMgmiyK0tt7KmyHSFe6AS3/FdimGJBlNVGwMDSFsF9VjYX1bcI6RM0wFnqKe2qE65RY
29Nwl5IswFRTD0Ri08mSRkgo4RYiV9/F5eAeYZQ/ayLY50mLchVXkd/UzZzuwwE7gAbrtCywH73+
99M8PlMNVJGWuOpwL0E2bOhFMlRbM/GGOP/CE2Q/55fGDahNRAfL9shAi8juFoFm9UppLaSiL5Ce
FQSqDPPKPPKzjoFG/hTPYZgHA9O7pGXT9LvZe7Ajbt7YVmfyVFaolVFylHZGjWi==
HR+cPm+QJJEQURO44oJO42pWVIWpt2923FetqxJ8WxwpW+8tLoAHFrzOYhqTl36rmzyKGVRO6FHl
4vJA+87LBkdhbMH0tzLy45Z3qgnOFo3d900HkJRdUwHgJit9PxHSm5GTHxNE7nBy0t/lbGedlY6m
ihKsukd9z50Ryb55WHcsuGYSp0y+zHgGvnaiJp/WklZ4BsJuTOnoTNbr7RzMI+L3HsUUeSE/A87D
j9PO9f+V3rQYOn6abFGuNGE+ApfxwGGocvGBC04pCjm0rd7lwHN9DBhrNHnby5SgAYU7OIt6ptUw
Pu6BRDbwwKfWwzOEX6LDa0jy63hzxrg4q7rGCdE7S5EqCWv3bau5WhAfRJSlVirM78GxgXEhNrCI
ScXJe9xRNCwN0zXBN9p+GJEbxkVYcFOWn3Pu8Qr6qMcMP74Xi4pNttSf59z8KvMaMLpym1dn6ltw
tQBzRoLoLmja0iBLBeXO2IaaBg4OdG8QlFCsTgnJIwy/mAEdl0REMcQZj7BWuZLWbApx2LJkuyJm
sQIjdO9nR7p4qcRQe/oVbuwVLuv0r4160HMFhVb7wKmKSzUEL5NGm00wqcGDoii5dCb5mn2hkzFY
1ZW/WVCjIMo3t+Akx72lrKcC/qaoWLljERrDhhFaTP0xYyThADc0in1UTmEiFoI5iOz/e8iQ/dte
w310Nz1Tj2K8sRLwnrZd7fAe5C7zQ1WFRiQRO2kOLEeTuwOUq58MvmNOFXWioc0TQs2RIdRMams1
TdoHm+HyZX5iOGBrV6ZBMtubzvX+Fy01Wf40Xc/y5kHkmZMZ5AUEbPSN+NY0ci5auANzjF4bT/q7
bz9hVLSbeoNkH4RiwsOwHgr4aknQIGvxI42esSmGGYzx1IuIpFJ5gNMckj6MfW==
